package com.shixing.sxedit.delegate;


import com.shixing.sxedit.SXVideoEffect;

import java.util.List;

public interface SXVideoEffectDelegate {

    /**
     * 添加视频特效，时间处理方式为重复（超出时间自动循环）
     *
     * @param videoEffectPath 资源路径
     * @param duration, 时长, 单位:秒
     * @param index, 添加的位置，-1 表示在末尾追加
     * @return 视频特效对象，失败返回null
     */
    SXVideoEffect addVideoEffect(String videoEffectPath, double duration, int index);

    /**
     * 通过复制已有的effect添加视频特效
     *
     * @param effect 要复制的对象
     * @param index, 添加的位置，-1 表示在末尾追加
     * @return 新的视频特效对象，失败返回null
     */
    SXVideoEffect addVideoEffectByCopy(SXVideoEffect effect, int index);

    /**
     * 移除视频特效
     *
     * @param videoEffectId 视频特效ID
     * @return 移除成功返回true，否则返回false
     */
    boolean removeVideoEffect(String videoEffectId);

    /**
     * 获取视频特效
     *
     * @param videoEffectId 视频特效ID
     * @return SXVideoEffect
     * */
    SXVideoEffect getVideoEffect(String videoEffectId);

    /**
     * 获取所有视频特效
     *
     * @return 视频特效对象List集合
     */
    List<SXVideoEffect> getVideoEffects();

    /**
     * 获取视频特效数
     *
     * @return int
     * */
    int getNumVideoEffects();
}